#
# spec file for package direnv
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gopackagepath github.com/direnv/direnv
Name:           direnv
Version:        2.15.2
Release:        lp150.1.2
Summary:        Unclutter a .profile
License:        MIT
Group:          Productivity/File utilities
Url:            http://direnv.net/
Source:         https://github.com/direnv/direnv/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  go >= 1.5
BuildRequires:  make

%description
direnv is an environment switcher for the shell. It knows how to hook into
bash, zsh, tcsh and fish shell to load or unload environment variables depending
on the current directory. This allows to have project-specific environment
variables and not clutter the "~/.profile" file.

%prep
%setup -q
mkdir -p "$HOME/go/src/$(dirname "%{gopackagepath}")"
cd ..
ln -sf `pwd`/%{name}-%{version} "$HOME/go/src/%{gopackagepath}"

%build
cd "$HOME/go/src/%{gopackagepath}"
make %{?_smp_mflags}

%install
cd "$HOME/go/src/%{gopackagepath}"
%make_install DESTDIR=%{buildroot}%{_prefix}

%files
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}
%{_mandir}/man1/%{name}-stdlib.1%{ext_man}
%{_mandir}/man1/%{name}.toml.1%{ext_man}

%changelog
* Mon Feb 26 2018 idonmez@suse.com
- Update to 2.15.2
  + Add support for allow folder whitelist (#332)
  + TOML configuration file! (#332, #337)
  + Add support for go 1.10 (#339)
* Sun Jan 21 2018 jengelh@inai.de
- Avoid specific user context in summary.
* Sat Dec 23 2017 avindra@opensuse.org
- Update to 2.14.0
  + support for Pipenv layout
  + version: make public
  + edit: run the command through bash
- Includes fix from 2.13.3
  + fix loading issue on macOS
- Includes fixes from 2.13.2
  + edit: fix path escaping
  + stdlib: fix find_up
  + stdlib: use absolute path in source_up
  + go-dotenv: update to latest master to fix a parsing error
  + remove ruby as a build dependency
* Mon Oct 16 2017 aavindraa@gmail.com
- General packaging cleanups
  - Drop _service file in favor of Github archive url
  - Explicitly list man pages (without wildcard)
  - Lint with spec-cleaner
- Update to 2.13.1
  + FIX: stdlib: make direnv_layout_dir lazy (#298)
- Includes 2.13.0:
  + NEW: stdlib: configurable direnv_layout_dir
  + CHANGE: stdlib: source the direnvrc directly
  + FIX: permit empty NODE_VERSION_PREFIX variable
  + FIX: pwd: Don't use -P to remove symlinks (#295)
  + FIX: also reload when mtime goes back in time
  + FIX: Prevent $HOME path from being striked (#287)
  + BUILD: use the new dep tool to manage dependencies
  + BUILD: dotenv: move to vendor folder
- Includes 2.12.x:
  + stdlib layout_python: fixes on no arg
  + FIX: stdlib path_add(), see #278
  + FIX: install from source instructions
  + NEW: support multiple items in path_add and PATH_add (#276)
  + NEW: add a configurable DIRENV_WARN_TIMEOUT option (#273)
  + CHANGE: rewrite the dotenv parsing, now supports commented lines
  + CHANGE: pass additional args to virtualenv (#261)
  + FIX: stdlib watch_file(): escaping fix
  + FIX: only output color if $TERM is not dumb (#264)
  + FIX: the watch_file documentation
- Includes 2.11.x:
  + FIX: node version sorting (#255)
  + FIX: Typo in MANPATH_add always generates "PATH missing" error. (#256)
  + FIX: only deploy the go 1.8 version
  + NEW: stdlib.sh: introduce MANPATH_add (#248)
  + NEW: provide packages using the equinox service
  + CHANGE: test direnv with go 1.8 (#254)
  + FIX: Add warning about source_env/up
  + FIX: go-md2man install instruction
- Includes 2.10.0:
  + NEW: use guix (#242)
  + CHANGE: use go-md2man to generate the man pages
  + FIX: tcsh escaping (#241)
  + FIX: doc typos and rewords (#226)
- Includes 2.9.0:
  + NEW: use_nix() is now watching default.nix and shell.nix
  + NEW: Allow to fix the bash path at built time
  + FIX: Panic on direnv current with no argument
  + FIX: Permit empty NODE_VERSION_PREFIX variable
  + FIX: layout_python: fail properly when python is not found
* Thu Apr 28 2016 fcastelli@suse.com
- Initial package release 2.8.1
